import { world, EquipmentSlot, GameMode, Player } from '@minecraft/server';

const Crucifix = {


    onUse({ source }) {

        source.playSound("random.totem");
        source.runCommand("effect @e[r=5, family=monster] wither 10 3 true");
        source.runCommand("effect @e[r=5, family=monster] weakness 10 4 true");
        source.runCommand("effect @e[r=5, family=monster] slowness 10 4 true");
        source.addEffect("regeneration", 100, {
            amplifier: 2,
            showParticles: true
        });
        if (!(source instanceof Player)) return;

        const equippable = source.getComponent("minecraft:equippable");
        if (!equippable) return;

        const mainhand = equippable.getEquipmentSlot(EquipmentSlot.Mainhand);
        if (!mainhand.hasItem()) return;

        // Apply durability damage when not in creative mode
        if (source.getGameMode() === GameMode.creative) return;

        const itemStack = mainhand.getItem(); // Allows us to get item components

        const durability = itemStack.getComponent("minecraft:durability");
        if (!durability) return;

        // Factor in unbreaking enchantment
        const enchantable = itemStack.getComponent("minecraft:enchantable");
        const unbreakingLevel = enchantable?.getEnchantment("unbreaking")?.level;

        const damageChance = durability.getDamageChance(unbreakingLevel) / 100;

        if (Math.random() > damageChance) return; // Randomly skip damage based on unbreaking level

        // Damage the item
        const shouldBreak = durability.damage === durability.maxDurability;

        if (shouldBreak) {
            mainhand.setItem(undefined); // Remove the item
            source.playSound("random.break"); // Play break sound
        } else {
            durability.damage++; // Increase durability damage
            mainhand.setItem(itemStack); // Update item in main hand
        }
    }
}
world.beforeEvents.worldInitialize.subscribe(({ itemComponentRegistry }) => {
    itemComponentRegistry.registerCustomComponent("mori:crucifix_item", Crucifix);
});